Version history
===============

This library adheres to `Semantic Versioning <http://semver.org/>`_.

**2.0.0** (2016-05-11)

- **BACKWARD INCOMPATIBLE** Migrated to Asphalt 2.0
- Allowed combining ``gateways`` with default parameters

**1.1.0** (2016-01-02)

- Added typeguard checks to fail early if arguments of wrong types are passed to functions

**1.0.1** (2015-11-20)

- Fixed the Asphalt dependency specification to work with setuptools older than 8.0

**1.0.0** (2015-05-16)

- Initial release
